@@ -1,6 +1,8 @@
 from __future__ import annotations
 
+import inspect
 import itertools
+from enum import Enum
 from functools import partial
 from pathlib import Path
 from typing import Callable
@@ -12,6 +14,7 @@ from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QDoubleValidator
 from PyQt5.QtGui import QIntValidator
 from PyQt5.QtWidgets import QCheckBox
+from PyQt5.QtWidgets import QComboBox
 from PyQt5.QtWidgets import QHBoxLayout
 from PyQt5.QtWidgets import QLabel
 from PyQt5.QtWidgets import QLineEdit
@@ -19,22 +22,85 @@ from PyQt5.QtWidgets import QVBoxLayout
 from PyQt5.QtWidgets import QWidget
 
 from .gui import IconLabel
+from .utils import combo_box_from_enum
+from .utils import combo_box_from_list
 
 HERE = Path(__file__).parent.resolve()
 
 
 class TypeObject:
+    def __init__(self, name: str = None):
+        self.name = name
+
     @property
     def __name__(self):
-        return self.__class__.__name__
+        return self.name or self.__class__.__name__
+
+    def get_widget(self):
+        raise NotImplementedError
+
+
+class UQWidget(QWidget):
+    def __init__(self):
+        super().__init__()
+
+    def get_value(self):
+        raise NotImplementedError
+
+
+class Callback(TypeObject):
+    def __init__(self, func: Callable, default: Callable = None, name: str = None):
+        super().__init__(name=name)
+        self.func = func
+        self.default_func = default
+
+    def get_widget(self):
+        return CallbackWidget(self.func, self.default_func)
+
+
+class CallbackWidget(UQWidget):
+    def __init__(self, func: Callable, default_func: Callable):
+        super().__init__()
+
+        hbox = QHBoxLayout()
+        hbox.setContentsMargins(0, 0, 0, 0)
+        hbox.setSpacing(0)
+
+        self.func_rc = func()
+
+        if isinstance(self.func_rc, (list, tuple)):
+            self.widget:QComboBox = combo_box_from_list(self.func_rc)
+            if default_func is not None:
+                self.widget.setCurrentText(str(default_func()))
+        elif inspect.isclass(self.func_rc) and issubclass(self.func_rc, Enum):
+            self.widget: QComboBox = combo_box_from_enum(self.func_rc)
+            if default_func is not None:
+                self.widget.setCurrentText(default_func().name)
+        else:
+            self.widget = QLineEdit()
+            self.widget.setPlaceholderText(str(self.func_rc))
+
+        hbox.addWidget(self.widget)
+
+        self.setContentsMargins(0, 0, 0, 0)
+        self.setLayout(hbox)
+
+    def get_value(self):
+        if not isinstance(self.widget, QComboBox):
+            return self.widget.displayText() or self.widget.placeholderText()
+
+        if isinstance(self.func_rc, (list, tuple)):
+            return self.func_rc[self.widget.currentIndex()]
+        else:
+            return self.func_rc[self.widget.currentText()]
 
 
 class ListList(TypeObject):
     """
     A TypeObject for a List of Lists.
     """
-    def __init__(self, literals: List[Union[str, Callable]], defaults: List = None):
-        super().__init__()
+    def __init__(self, literals: List[Union[str, Callable]], defaults: List = None, name: str = None):
+        super().__init__(name=name or "list of lists")
         self._literals = literals
         self._defaults = defaults or []
 
@@ -48,14 +114,6 @@ class ListList(TypeObject):
         return ListListWidget(self)
 
 
-class UQWidget(QWidget):
-    def __init__(self):
-        super().__init__()
-
-    def get_value(self):
-        raise NotImplementedError
-
-
 class ListListWidget(UQWidget):
     def __init__(self, type_object: ListList):
         super().__init__()
